pywws.Forecast — pywws v12.11_95babb0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pywws v12.11_95babb0 documentation »
- Python programs and modules »

# pywws.Forecast

Predict future weather using recent data.

usage: python Forecast.py [options] data_dir options are:

> -h | –help display this help

data_dir is the root directory of the weather data

Functions

`Zambretti`(params, hourly_data) |
`main`([argv]) |

`pywws.Forecast.` `ZambrettiCode`(params, hourly_data)

`pywws.Forecast.` `Zambretti`(params, hourly_data)

`pywws.Forecast.` `main`(argv=None)

### Navigation

- index
- modules |
- next |
- previous |
- pywws v12.11_95babb0 documentation »
- Python programs and modules »